"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SubscriptionServiceComponent = void 0;
const tslib_1 = require("tslib");
// Copyright (c) 2023 Sourcefuse Technologies
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
const core_1 = require("@loopback/core");
const rest_1 = require("@loopback/rest");
const core_2 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const keys_1 = require("./keys");
const repositories_1 = require("./repositories");
const controllers_1 = require("./controllers");
const models_1 = require("./models");
let SubscriptionServiceComponent = class SubscriptionServiceComponent {
    constructor(application, notifConfig) {
        var _a;
        this.application = application;
        this.notifConfig = notifConfig;
        this.providers = {};
        this.bindings = [];
        this.providers = {};
        // Mount core component
        this.application.component(core_2.CoreComponent);
        this.application.api({
            openapi: '3.0.0',
            info: {
                title: 'Audit Service',
                version: '1.0.0',
            },
            paths: {},
            components: {
                securitySchemes: core_2.SECURITY_SCHEME_SPEC,
            },
            servers: [{ url: '/' }],
        });
        if (!((_a = this.notifConfig) === null || _a === void 0 ? void 0 : _a.useCustomSequence)) {
            // Mount default sequence if needed
            this.setupSequence();
        }
        this.repositories = [
            repositories_1.BillingCycleRepository,
            repositories_1.CurrencyRepository,
            repositories_1.PlanItemRepository,
            repositories_1.PlanRepository,
            repositories_1.ResourceRepository,
            repositories_1.ServiceRepository,
            repositories_1.SubscriptionRepository,
        ];
        this.models = [
            models_1.BillingCycle,
            models_1.Currency,
            models_1.PlanItem,
            models_1.Plan,
            models_1.Resource,
            models_1.Service,
            models_1.Subscription,
        ];
        this.controllers = [
            controllers_1.BillinCycleController,
            controllers_1.HomePageController,
            controllers_1.PingController,
            controllers_1.CurrencyController,
            controllers_1.PlanItemController,
            controllers_1.PlanController,
            controllers_1.ResourceController,
            controllers_1.ServiceController,
            controllers_1.SubscriptionController,
            controllers_1.PlanSubscriptionController,
        ];
    }
    /**
     * Setup ServiceSequence by default if no other sequnce provided
     *
     */
    setupSequence() {
        this.application.sequence(core_2.ServiceSequence);
        // Mount authentication component for default sequence
        this.application.component(loopback4_authentication_1.AuthenticationComponent);
        // Mount bearer verifier component
        this.application.bind(core_2.BearerVerifierBindings.Config).to({
            authServiceUrl: '',
            type: core_2.BearerVerifierType.service,
        });
        this.application.component(core_2.BearerVerifierComponent);
        // Mount authorization component for default sequence
        this.application.bind(loopback4_authorization_1.AuthorizationBindings.CONFIG).to({
            allowAlwaysPaths: ['/explorer'],
        });
        this.application.component(loopback4_authorization_1.AuthorizationComponent);
    }
};
exports.SubscriptionServiceComponent = SubscriptionServiceComponent;
exports.SubscriptionServiceComponent = SubscriptionServiceComponent = tslib_1.__decorate([
    tslib_1.__param(0, (0, core_1.inject)(core_1.CoreBindings.APPLICATION_INSTANCE)),
    tslib_1.__param(1, (0, core_1.inject)(keys_1.SubscriptionServiceBindings.Config, { optional: true })),
    tslib_1.__metadata("design:paramtypes", [rest_1.RestApplication, Object])
], SubscriptionServiceComponent);
//# sourceMappingURL=component.js.map